.. _resource-ref:

Resource Reference
==================

In this chapter we describe the different plugins bundled with Fastr (e.g.
IOPlugins, ExecutionPlugins). The reference is build automatically from code,
so after installing a new plugin the documentation has to be rebuild for it to
be included in the docs.

.. include:: ../fastr.ref.ioplugins.rst
.. include:: ../fastr.ref.collectorplugins.rst
